@@ -28,6 +28,14 @@ class Pg:
         self.table = table
 
     
+    async def add_column(self, column_name, data_type):
+        await self.pool.execute(f"ALTER TABLE {self.table} ADD COLUMN {column_name} {data_type}")
+
+
+    async def remove_column(self, column_name, data_type):
+        await self.pool.execute(f"ALTER TABLE {self.table} DROP COLUMN {column_name} {data_type}")
+
+
     async def ncfetchs(self):
         content = await self.pool.fetch(f"SELECT * FROM {self.table}")
  
@@ -137,4 +145,7 @@ class Pg:
         if not columns:
             return await self.pool.execute(f'UPDATE {self.table} SET {one_column}', *opt.values())
 
-        await self.pool.execute(f'UPDATE {self.table} SET {one_column} WHERE {columns}', *opt.values())
\ No newline at end of file
+        await self.pool.execute(f'UPDATE {self.table} SET {one_column} WHERE {columns}', *opt.values())
+
+
+    
\ No newline at end of file
